@@ -21,14 +21,16 @@
 import unittest2
 from stalker import Entity, FilenameTemplate, Type
 
+
 # a test class
 class Asset(object):
     pass
 
+
 class FilenameTemplateTester(unittest2.TestCase):
     """tests the stalker.models.template.FilenameTemplate class
     """
-    
+
     def setUp(self):
         """setup the test
         """
@@ -40,33 +42,34 @@ class FilenameTemplateTester(unittest2.TestCase):
                 target_entity_type="FilenameTemplate"
             ),
             "path": "ASSETS/{{asset.code}}/{{task.type.code}}/",
-            "filename": "{{asset.code}}_{{version.take}}_{{task.type.code}}_"\
-                         "{{version.version}}_{{user.initials}}",
+            "filename": "{{asset.code}}_{{version.take}}_{{task.type.code}}_" \
+                        "{{version.version}}_{{user.initials}}",
             "output_path": "",
             "target_entity_type": Asset,
         }
         self.filename_template = FilenameTemplate(**self.kwargs)
-    
+
     def test___auto_name__class_attribute_is_set_to_False(self):
         """testing if the __auto_name__ class attribute is set to False for
         Asset class
         """
         self.assertFalse(FilenameTemplate.__auto_name__)
-    
+
     def test_filename_template_is_not_strictly_typed(self):
         """testing if the FilenameTemplate class is not strictly typed
         """
         self.kwargs.pop("type")
         # no errors
-        new_ft = FilenameTemplate(**self.kwargs)
-    
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertIsInstance(ft, FilenameTemplate)
+
     def test_target_entity_type_argument_is_skipped(self):
         """testing if a TypeError will be raised when the target_entity_type
         argument is skipped
         """
         self.kwargs.pop("target_entity_type")
         self.assertRaises(TypeError, FilenameTemplate, **self.kwargs)
-    
+
     def test_target_entity_type_argument_is_None(self):
         """testing if a TypeError will be raised when the target_entity_type
         argument is given as None
@@ -92,37 +95,39 @@ class FilenameTemplateTester(unittest2.TestCase):
         target_entity_type is given as a class
         """
         self.kwargs["target_entity_type"] = Asset
-        new_filenameTemplate = FilenameTemplate(**self.kwargs)
-        self.assertEqual(new_filenameTemplate.target_entity_type, "Asset")
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertEqual(ft.target_entity_type, "Asset")
 
     def test_path_argument_is_skipped(self):
         """testing if nothing happens when the path argument is skipped
         """
         self.kwargs.pop("path")
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertIsInstance(ft, FilenameTemplate)
 
     def test_path_argument_skipped_path_attribute_is_empty_string(self):
         """testing if the path attribute is an empty string if the
         path argument is skipped
         """
         self.kwargs.pop("path")
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
-        self.assertEqual(new_fileTemplate.path, "")
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertEqual(ft.path, "")
 
     def test_path_argument_is_None_path_attribute_is_empty_string(self):
         """testing if the path attribute is an empty string when the
         path argument is None
         """
         self.kwargs["path"] = None
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
-        self.assertEqual(new_fileTemplate.path, "")
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertEqual(ft.path, "")
 
     def test_path_argument_is_empty_string(self):
         """testing if nothing happens when the path argument is empty
         string
         """
         self.kwargs["path"] = ""
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertIsInstance(ft, FilenameTemplate)
 
     def test_path_attribute_is_empty_string(self):
         """testing if nothing happens when the path attribute is set to
@@ -150,37 +155,39 @@ class FilenameTemplateTester(unittest2.TestCase):
         """testing if nothing happens when the filename argument is skipped
         """
         self.kwargs.pop("filename")
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertIsInstance(ft, FilenameTemplate)
 
     def test_filename_argument_skipped_filename_attribute_is_empty_string(self):
         """testing if the filename attribute is an empty string if the
         filename argument is skipped
         """
         self.kwargs.pop("filename")
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
-        self.assertEqual(new_fileTemplate.filename, "")
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertEqual(ft.filename, "")
 
     def test_filename_argument_is_None_filename_attribute_is_empty_string(self):
         """testing if the filename attribute is an empty string when the
         filename argument is None
         """
         self.kwargs["filename"] = None
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
-        self.assertEqual(new_fileTemplate.filename, "")
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertEqual(ft.filename, "")
 
     def test_filename_argument_is_empty_string(self):
         """testing if nothing happens when the filename argument is empty
         string
         """
         self.kwargs["filename"] = ""
-        new_fileTemplate = FilenameTemplate(**self.kwargs)
+        ft = FilenameTemplate(**self.kwargs)
+        self.assertIsInstance(ft, FilenameTemplate)
 
     def test_filename_attribute_is_empty_string(self):
         """testing if nothing happens when the filename attribute is set to
         empty string
         """
         self.filename_template.filename = ""
-    
+
     def test_filename_argument_is_not_string(self):
         """testing if a TypeError will be raised when filename argument is not
         string
@@ -188,7 +195,7 @@ class FilenameTemplateTester(unittest2.TestCase):
         test_value = list("a list from a string")
         self.kwargs["filename"] = test_value
         self.assertRaises(TypeError, FilenameTemplate, **self.kwargs)
-    
+
     def test_filename_attribute_is_not_string(self):
         """testing if the given value converted to string for the filename
         attribute
@@ -196,47 +203,47 @@ class FilenameTemplateTester(unittest2.TestCase):
         test_value = list("a list from a string")
         self.assertRaises(TypeError, self.filename_template, "filename",
                           test_value)
-    
+
     def test_equality(self):
         """testing the equality of FilenameTemplate objects
         """
-        new_filenameTemplate1 = FilenameTemplate(**self.kwargs)
-        
+        ft1 = FilenameTemplate(**self.kwargs)
+
         new_entity = Entity(**self.kwargs)
-        
+
         self.kwargs["target_entity_type"] = "Entity"
-        new_filenameTemplate2 = FilenameTemplate(**self.kwargs)
-        
+        ft2 = FilenameTemplate(**self.kwargs)
+
         self.kwargs["path"] = "different path"
-        new_filenameTemplate3 = FilenameTemplate(**self.kwargs)
-        
+        ft3 = FilenameTemplate(**self.kwargs)
+
         self.kwargs["filename"] = "different filename"
-        new_filenameTemplate4 = FilenameTemplate(**self.kwargs)
-        
-        self.assertTrue(self.filename_template == new_filenameTemplate1)
+        ft4 = FilenameTemplate(**self.kwargs)
+
+        self.assertTrue(self.filename_template == ft1)
         self.assertFalse(self.filename_template == new_entity)
-        self.assertFalse(new_filenameTemplate1 == new_filenameTemplate2)
-        self.assertFalse(new_filenameTemplate2 == new_filenameTemplate3)
-        self.assertFalse(new_filenameTemplate3 == new_filenameTemplate4)
+        self.assertFalse(ft1 == ft2)
+        self.assertFalse(ft2 == ft3)
+        self.assertFalse(ft3 == ft4)
 
     def test_inequality(self):
         """testing the inequality of FilenameTemplate objects
         """
-        new_filenameTemplate1 = FilenameTemplate(**self.kwargs)
-        
+        ft1 = FilenameTemplate(**self.kwargs)
+
         new_entity = Entity(**self.kwargs)
-        
+
         self.kwargs["target_entity_type"] = "Entity"
-        new_filenameTemplate2 = FilenameTemplate(**self.kwargs)
-        
+        ft2 = FilenameTemplate(**self.kwargs)
+
         self.kwargs["path"] = "different path"
-        new_filenameTemplate3 = FilenameTemplate(**self.kwargs)
-        
+        ft3 = FilenameTemplate(**self.kwargs)
+
         self.kwargs["filename"] = "different filename"
-        new_filenameTemplate4 = FilenameTemplate(**self.kwargs)
-        
-        self.assertFalse(self.filename_template != new_filenameTemplate1)
+        ft4 = FilenameTemplate(**self.kwargs)
+
+        self.assertFalse(self.filename_template != ft1)
         self.assertTrue(self.filename_template != new_entity)
-        self.assertTrue(new_filenameTemplate1 != new_filenameTemplate2)
-        self.assertTrue(new_filenameTemplate2 != new_filenameTemplate3)
-        self.assertTrue(new_filenameTemplate3 != new_filenameTemplate4)
+        self.assertTrue(ft1 != ft2)
+        self.assertTrue(ft2 != ft3)
+        self.assertTrue(ft3 != ft4)
